# ctle
C++ Template Library Extension classes - Extension classes for Windows and Linux STL

## license
Copyright (c) 2022-2024 Ulrik Lindahl
Licensed under the MIT license https://github.com/Cooolrik/ctle/blob/main/LICENSE
